"""
Context Module

Provides environmental awareness to Zenus.
"""

from zenus_core.context.context_manager import ContextManager, get_context_manager

__all__ = ["ContextManager", "get_context_manager"]
